@@ -7,9 +7,9 @@ use Carp         ( 'confess' );
 use Scalar::Util ( 'blessed' );
 use base qw(
     WebService::Shippo::Resource
-    WebService::Shippo::Creator
-    WebService::Shippo::Fetcher
-    WebService::Shippo::Updater
+    WebService::Shippo::Create
+    WebService::Shippo::Fetch
+    WebService::Shippo::Update
 );
 
 sub api_resource () { 'carrier_accounts' }
@@ -87,7 +87,7 @@ WebService::Shippo::CarrierAccount - Carrier Account class
 
 =head1 VERSION
 
-version 0.0.17
+version 0.0.18
 
 =head1 DESCRIPTION
 
