@@ -6,9 +6,9 @@ package WebService::Shippo::CarrierAccounts;
 require WebService::Shippo::CarrierAccount;
 use base qw(
     WebService::Shippo::Collection
-    WebService::Shippo::Creator
-    WebService::Shippo::Fetcher
-    WebService::Shippo::Updater
+    WebService::Shippo::Create
+    WebService::Shippo::Fetch
+    WebService::Shippo::Update
 );
 
 sub item_class () { 'WebService::Shippo::CarrierAccount' }
@@ -32,7 +32,7 @@ WebService::Shippo::CarrierAccounts - Carrier Account collection class
 
 =head1 VERSION
 
-version 0.0.17
+version 0.0.18
 
 =head1 DESCRIPTION
 
