@@ -5,8 +5,8 @@ use MRO::Compat 'c3';
 package WebService::Shippo::CustomsDeclaration;
 use base qw(
     WebService::Shippo::Resource
-    WebService::Shippo::Creator
-    WebService::Shippo::Fetcher
+    WebService::Shippo::Create
+    WebService::Shippo::Fetch
 );
 
 sub api_resource () { 'customs/declarations' }
@@ -32,7 +32,7 @@ WebService::Shippo::CustomsDeclaration - Customs Declaration class
 
 =head1 VERSION
 
-version 0.0.17
+version 0.0.18
 
 =head1 DESCRIPTION
 
