@@ -6,8 +6,8 @@ package WebService::Shippo::CustomsDeclarations;
 require WebService::Shippo::CustomsDeclaration;
 use base qw(
     WebService::Shippo::Collection
-    WebService::Shippo::Creator
-    WebService::Shippo::Fetcher
+    WebService::Shippo::Create
+    WebService::Shippo::Fetch
 );
 
 sub item_class () { 'WebService::Shippo::CustomsDeclaration' }
@@ -31,7 +31,7 @@ WebService::Shippo::CustomsDeclarations - Customs Declaration collection class
 
 =head1 VERSION
 
-version 0.0.17
+version 0.0.18
 
 =head1 DESCRIPTION
 
