@@ -6,7 +6,7 @@ package WebService::Shippo::Rate;
 require WebService::Shippo::Shipment;
 use base qw(
     WebService::Shippo::Resource
-    WebService::Shippo::Fetcher
+    WebService::Shippo::Fetch
 );
 
 sub api_resource () { 'rates' }
@@ -38,7 +38,7 @@ WebService::Shippo::Rate - Rate class
 
 =head1 VERSION
 
-version 0.0.17
+version 0.0.18
 
 =head1 DESCRIPTION
 
