@@ -5,8 +5,8 @@ use MRO::Compat 'c3';
 package WebService::Shippo::Refund;
 use base qw(
     WebService::Shippo::Resource
-    WebService::Shippo::Creator
-    WebService::Shippo::Fetcher
+    WebService::Shippo::Create
+    WebService::Shippo::Fetch
     WebService::Shippo::Async
 );
 
@@ -33,7 +33,7 @@ WebService::Shippo::CarrierAccount - Refund class
 
 =head1 VERSION
 
-version 0.0.17
+version 0.0.18
 
 =head1 DESCRIPTION
 
