@@ -6,11 +6,11 @@ package WebService::Shippo::Shipments;
 require WebService::Shippo::Shipment;
 use base qw(
     WebService::Shippo::Collection
-    WebService::Shippo::Creator
-    WebService::Shippo::Fetcher
+    WebService::Shippo::Create
+    WebService::Shippo::Fetch
 );
 
-sub item_class ()       { 'WebService::Shippo::Shipment' }
+sub item_class () { 'WebService::Shippo::Shipment' }
 
 sub collection_class () { __PACKAGE__ }
 
@@ -31,7 +31,7 @@ WebService::Shippo::Shipment - Shipment collection class
 
 =head1 VERSION
 
-version 0.0.17
+version 0.0.18
 
 =head1 DESCRIPTION
 
